@@ -19,12 +19,14 @@ class WildCard:
 class Tracker:
     """Keep track of what each next token should mean"""
 
-    def __init__(self, result, tokens):
+    def __init__(self, result, tokens, with_it_return_type=False):
         if result is None:
             self.result = []
         else:
             self.result = result
 
+        self.with_it_return_type = with_it_return_type
+
         self.single = None
         self.tokens = tokens
         self.groups = Group(root=True)
@@ -155,7 +157,7 @@ class Tracker:
 
         elif self.groups.starting_single:
             # Inside single signature, add to it
-            if tokenum == STRING:
+            if tokenum == STRING and not self.single.name:
                 self.single.name = value
                 self.single.args[0] = (
                     self.single.args[0][0],
@@ -421,13 +423,16 @@ class Tracker:
         args = self.single.args
         name = self.single.python_name
         comments = self.single.comments
+        return_type = self.single.return_type
+        if return_type is None and self.with_it_return_type:
+            return_type = True
 
         # Reset indentation to proper amount
         if not self.result or self.result[-1][0] != NAME:
             self.reset_indentation(self.indent_type * self.single.indent)
 
         # And add signature
-        self.result.extend(self.tokens.make_single(name, args, comments))
+        self.result.extend(self.tokens.make_single(name, args, comments, return_type))
         self.groups.finish_signature()
 
     def finish_hanging(self):
